==> jc-1.4.0.tar.gz: soot/jimple/toolkits/callgraph/MethodContext.h <==
// public final class soot.jimple.toolkits.callgraph.MethodContext

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5fce14a25e1f2147 soot_jimple_toolkits_callgraph_MethodContext

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_MethodContext_H_
#define _JC_soot_jimple_toolkits_callgraph_MethodContext_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_callgraph_MethodOrMethodContext$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_MethodContext$sub_refs	_jc_soot_jimple_toolkits_callgraph_MethodContext$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_MethodContext$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_MethodContext$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_MethodContext$refs	_jc_soot_jimple_toolkits_callgraph_MethodContext$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_MethodContext$nonrefs	_jc_soot_jimple_toolkits_callgraph_MethodContext$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object	_jc_soot_jimple_toolkits_callgraph_MethodContext$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_MethodContext$vmethods	_jc_soot_jimple_toolkits_callgraph_MethodContext$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_MethodContext$vtable	_jc_soot_jimple_toolkits_callgraph_MethodContext$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_MethodContext$vtype	_jc_soot_jimple_toolkits_callgraph_MethodContext$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_MethodContext$method$_init$5979cb1631b1371f(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_callgraph_MethodContext$method$context$a8db07e7ad32150d(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *);
extern jboolean _jc_soot_jimple_toolkits_callgraph_MethodContext$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_soot_jimple_toolkits_callgraph_MethodContext$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *);
extern struct _jc_soot_SootMethod$object *_jc_soot_jimple_toolkits_callgraph_MethodContext$method$method$e18b012c4969483d(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_callgraph_MethodContext$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_MethodContext$method_info$context$a8db07e7ad32150d;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_MethodContext$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_MethodContext$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_MethodContext$method_info$method$e18b012c4969483d;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_MethodContext$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_MethodContext$method$v$549f4b2eb03b7704(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_Object$object *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_MethodContext$vmethods {
	struct _jc_java_lang_Object$object	*(*context$a8db07e7ad32150d)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *);
	struct _jc_soot_SootMethod$object	*(*method$e18b012c4969483d)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_MethodContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_MethodContext$vmethods	soot_jimple_toolkits_callgraph_MethodContext;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_MethodContext$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_MethodContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_MethodContext$sub_refs {
	struct _jc_soot_SootMethod$object	*method;
	struct _jc_java_lang_Object$object	*context;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_MethodContext$refs {
    _jc_soot_jimple_toolkits_callgraph_MethodContext$sub_refs	soot_jimple_toolkits_callgraph_MethodContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_MethodContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_MethodContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_MethodContext$sub_nonrefs	soot_jimple_toolkits_callgraph_MethodContext;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object {
	_jc_soot_jimple_toolkits_callgraph_MethodContext$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_MethodContext$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_MethodContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_MethodContext$vtype _jc_soot_jimple_toolkits_callgraph_MethodContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_MethodContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_MethodContext$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_MethodContext_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/callgraph/MethodContext.h <==
// public final class soot.jimple.toolkits.callgraph.MethodContext

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5fce14a25e1f2147 soot_jimple_toolkits_callgraph_MethodContext

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_MethodContext_H_
#define _JC_soot_jimple_toolkits_callgraph_MethodContext_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_callgraph_MethodOrMethodContext$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_MethodContext$sub_refs	_jc_soot_jimple_toolkits_callgraph_MethodContext$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_MethodContext$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_MethodContext$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_MethodContext$refs	_jc_soot_jimple_toolkits_callgraph_MethodContext$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_MethodContext$nonrefs	_jc_soot_jimple_toolkits_callgraph_MethodContext$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object	_jc_soot_jimple_toolkits_callgraph_MethodContext$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_MethodContext$vmethods	_jc_soot_jimple_toolkits_callgraph_MethodContext$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_MethodContext$vtable	_jc_soot_jimple_toolkits_callgraph_MethodContext$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_MethodContext$vtype	_jc_soot_jimple_toolkits_callgraph_MethodContext$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_MethodContext$method$_init$5979cb1631b1371f(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_callgraph_MethodContext$method$context$a8db07e7ad32150d(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_callgraph_MethodContext$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_toolkits_callgraph_MethodContext$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_SootMethod$object *_jc_soot_jimple_toolkits_callgraph_MethodContext$method$method$e18b012c4969483d(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_callgraph_MethodContext$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_MethodContext$method_info$context$a8db07e7ad32150d;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_MethodContext$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_MethodContext$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_MethodContext$method_info$method$e18b012c4969483d;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_MethodContext$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_MethodContext$method$v$549f4b2eb03b7704(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_MethodContext$vmethods {
	struct _jc_java_lang_Object$object	*(*context$a8db07e7ad32150d)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *) _JC_JCNI_ATTR;
	struct _jc_soot_SootMethod$object	*(*method$e18b012c4969483d)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_MethodContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_MethodContext$vmethods	soot_jimple_toolkits_callgraph_MethodContext;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_MethodContext$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_MethodContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_MethodContext$sub_refs {
	struct _jc_soot_SootMethod$object	*method;
	struct _jc_java_lang_Object$object	*context;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_MethodContext$refs {
    _jc_soot_jimple_toolkits_callgraph_MethodContext$sub_refs	soot_jimple_toolkits_callgraph_MethodContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_MethodContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_MethodContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_MethodContext$sub_nonrefs	soot_jimple_toolkits_callgraph_MethodContext;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_MethodContext$object {
	_jc_soot_jimple_toolkits_callgraph_MethodContext$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_MethodContext$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_MethodContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_MethodContext$vtype _jc_soot_jimple_toolkits_callgraph_MethodContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_MethodContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_MethodContext$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_MethodContext_H_ */
